package ru.ulstu.extractor.ts.creator;

import org.springframework.stereotype.Component;
import ru.ulstu.extractor.branch.service.BranchService;
import ru.ulstu.extractor.gitrepository.model.GitRepository;
import ru.ulstu.extractor.gitrepository.service.GitRepositoryService;
import ru.ulstu.extractor.ts.model.TimeSeries;
import ru.ulstu.extractor.ts.model.TimeSeriesType;
import ru.ulstu.extractor.ts.service.TimeSeriesService;
import ru.ulstu.extractor.ts.util.Dummy;

import java.util.Collections;
import java.util.List;

@Component
public class AuthorsCommitTS extends AbstractTimeSeriesCreator {
    private final TimeSeriesService timeSeriesService;
    private final BranchService branchService;

    private final GitRepositoryService gitRepositoryService;

    public AuthorsCommitTS(TimeSeriesService timeSeriesService,
                           BranchService branchService,
                           GitRepositoryService gitRepositoryService) {
        this.timeSeriesService = timeSeriesService;
        this.branchService = branchService;
        this.gitRepositoryService = gitRepositoryService;
    }

    @Override
    public TimeSeriesType getTimeSeriesType() {
        return TimeSeriesType.AUTHOR_COMMITS;
    }

    @Override
    public List<TimeSeries> getTimeSeries(Integer repositoryId, String branchName) {
        GitRepository gitRepository = gitRepositoryService.findById(repositoryId);
        //TODO: добавить постраничное чтение
        return Collections.singletonList(
                new TimeSeries(
                        String.format("%s %s %s",
                                gitRepository.getName(),
                                branchName,
                                getTimeSeriesType().getDescription()),
                        branchService.findByRepositoryAndName(gitRepository, branchName),
                        getTimeSeriesType(),
                        Dummy.getDefaultTimeSeries()));
    }

    @Override
    public TimeSeriesService getTimeSeriesService() {
        return timeSeriesService;
    }
}
