package ru.ulstu.extractor.ts.creator;

import org.springframework.stereotype.Component;
import ru.ulstu.extractor.branch.service.BranchService;
import ru.ulstu.extractor.commit.model.Commit;
import ru.ulstu.extractor.commit.service.CommitService;
import ru.ulstu.extractor.gitrepository.model.FileChange;
import ru.ulstu.extractor.gitrepository.model.GitRepository;
import ru.ulstu.extractor.gitrepository.service.GitRepositoryService;
import ru.ulstu.extractor.ts.model.TimeSeries;
import ru.ulstu.extractor.ts.model.TimeSeriesType;
import ru.ulstu.extractor.ts.model.TimeSeriesValue;
import ru.ulstu.extractor.ts.service.TimeSeriesService;

import java.util.ArrayList;
import java.util.List;

@Component
public class FileTS extends AbstractTimeSeriesCreator {
    private final TimeSeriesService timeSeriesService;
    private final GitRepositoryService gitRepositoryService;
    private final CommitService commitService;
    private final BranchService branchService;

    public FileTS(TimeSeriesService timeSeriesService,
                  GitRepositoryService gitRepositoryService,
                  CommitService commitService,
                  BranchService branchService) {
        this.timeSeriesService = timeSeriesService;
        this.gitRepositoryService = gitRepositoryService;
        this.commitService = commitService;
        this.branchService = branchService;
    }

    @Override
    public List<TimeSeries> getTimeSeries(Integer repositoryId, String branchName) {
        GitRepository gitRepository = gitRepositoryService.findById(repositoryId);
        List<TimeSeries> timeSeriesResult = new ArrayList<>();
        List<Commit> commits = new ArrayList<>(commitService.findByRepositoryIdAndName(repositoryId, branchName));
        double value = 0;
        TimeSeries timeSeries = new TimeSeries(
                String.format("%s %s %s",
                        gitRepository.getName(),
                        branchName,
                        getTimeSeriesType().getDescription()),
                branchService.findByRepositoryAndName(gitRepository, branchName),
                getTimeSeriesType());
        for (Commit commit : commits) {
            for (FileChange fileChange : commit.getFileChanges()) {
                if ((fileChange.getAdded() != null) && (fileChange.getAdded())) {
                    value += 1;
                }
                if ((fileChange.getRemoved() != null) && (fileChange.getRemoved())) {
                    value -= 1;
                }
            }
            timeSeries.getValues().add(new TimeSeriesValue(commit.getDate(), value));
        }
        if (!timeSeries.getValues().isEmpty()) {
            timeSeriesResult.add(timeSeries);
        }
        return timeSeriesResult;
    }

    @Override
    public TimeSeriesService getTimeSeriesService() {
        return timeSeriesService;
    }

    @Override
    public TimeSeriesType getTimeSeriesType() {
        return TimeSeriesType.FILES;
    }
}
